@@ -32,6 +32,7 @@
 			17.11.2007 version 1.05
 			13.03.2008 version 1.06
 			11.04.2008 version 1.07
+			27.05.2008 version 1.08
 
 =head1 Methods
 
@@ -45,7 +46,7 @@ use base (qw/ctkBase/);
 
 use vars qw/$VERSION/;
 
-$VERSION = 1.07;
+$VERSION = 1.08;
 
 package std;
 
@@ -534,7 +535,7 @@ my $rW003 = $rW001 -> Label ( -background=>'#c0c0c0', -justify=>'left', -text=>'
 	$rv =  $mw->Show();
 	return undef if ($rv =~/Cancel/i);
 	my @sel = $rW002->curselection();
-	$rv = $args{-widgets}->[@sel];
+	$rv = $args{-widgets}->[$sel[0]];
 	return $rv;
 }
 
@@ -807,8 +808,8 @@ my $mw = $hwnd->ctkDialogBox(
 $mw->protocol('WM_DELETE_WINDOW',sub{1});
 
 
-## ctk: code generated by ctk_w version '3.099' 
-## ctk: instantiate and display widgets 
+## ctk: code generated by ctk_w version '3.099'
+## ctk: instantiate and display widgets
 
 my $wr_001 = $mw -> Scrolled ( 'Listbox' , -background , '#ffffff' , -selectmode , 'single' , -relief , 'sunken' , -scrollbars , 'e'  ) -> pack(-anchor=>'nw', -side=>'top', -pady=>5, -fill=>'both', -expand=>1, -padx=>5);
 &dlg_selectCursorInit($wr_001);
@@ -822,14 +823,14 @@ $rv =  $mw->Show();
 
 if ($rv =~/^OK/i) {
 		my @sel = $wr_001->curselection();
-		$rv = $wr_001->get(@sel);
-} else { 
+		$rv = $wr_001->get($sel[0]);
+} else {
 		undef $rv
 }
 
 return $rv;
 
-} ## end of dlg_selectCursor 
+} ## end of dlg_selectCursor
 
 ## ctk: end of dialog code
 ## ctk: callbacks
@@ -982,32 +983,32 @@ sub dlg_codeOptions {
 			$new_file_opt{'subWidgetList'} = $a if(defined ($a));
 			&main::trace("$a");
 			},$db],-bg => '#FFFFFF')->pack(-side, 'left', -expand ,1 , -fill , 'x');
-	$frm3->Button(-text=>'ConfigSpec',-relief => 'raised',
+	$frm3->Button(-text=>'ConfigSpecs',-relief => 'raised',
 		-command => [sub{
 			my $hwnd = shift;
 			return undef unless $new_file_opt{'code'} == 3;
 			my $a = $hwnd->ctkDlgConfigSpec(-buttons =>[qw/Ok Cancel/]);
-			my $w = exists $new_file_opt{'ConfigSpec'} ? $new_file_opt{'ConfigSpec'} : '{}';
+			my $w = exists $new_file_opt{'ConfigSpecs'} ? $new_file_opt{'ConfigSpecs'} : '{}';
 			$w = eval "$w";
 			$a->optionsList($w);
 			my $reply = $a->Show();
 			if ($reply =~ /ok/i) {
-				$new_file_opt{'ConfigSpec'} = ctkBase->dump($a->optionsList);
-				&main::trace("ConfigSpec = ".$new_file_opt{'ConfigSpec'})
+				$new_file_opt{'ConfigSpecs'} = ctkBase->dump($a->optionsList);
+				&main::trace("ConfigSpecs = ".$new_file_opt{'ConfigSpecs'})
 			} else {}
 			},$db],-bg => '#FFFFFF')->pack(-side, 'left', -expand ,1 , -fill , 'x');
-	$frm3->Button(-text=>'Delegate',-relief => 'raised',
+	$frm3->Button(-text=>'Delegates',-relief => 'raised',
 		-command => [sub{
 			my $hwnd = shift;
 			return undef unless $new_file_opt{'code'} == 3;
 			my $a = $hwnd->ctkDlgDelegate(-buttons =>[qw/Ok Cancel/]);
-			my $w = exists $new_file_opt{'delegate'} ? $new_file_opt{'delegate'} : '{}';
+			my $w = exists $new_file_opt{'Delegates'} ? $new_file_opt{'Delegates'} : '{}';
 			$w = eval "$w";
 			$a->delegateList($w);
 			my $reply = $a->Show();
 			if ($reply =~ /ok/i) {
-				$new_file_opt{'delegate'} = ctkBase->dump($a->delegateList);
-				&main::trace("delegate = ".$new_file_opt{'delegate'});
+				$new_file_opt{'Delegates'} = ctkBase->dump($a->delegateList);
+				&main::trace("Delegates = ".$new_file_opt{'Delegates'});
 				} else {}
 			},$db],-bg => '#FFFFFF')->pack(-side, 'left', -expand ,1 , -fill , 'x');
 	$row = 0;
@@ -1160,7 +1161,7 @@ $rW012 = $rLeftFrame -> Frame ( -relief=>'flat' ) -> pack(-anchor=>'sw', -side=>
 $rW013 = $rW012 -> Button ( -command => sub{&main::addGlobal($rW024)},-background=>'#ffffff', -text=>'Add', -state=>'normal' ) -> pack(-anchor=>'nw', -side=>'left', -fill=>'x', -expand=>1);
 $rW016 = $rW012 -> Button ( -command => sub{&main::editGlobal($rW024)},-background=>'#ffffff', -text=>'Edit', -state=>'normal' ) -> pack(-anchor=>'nw', -side=>'left', -fill=>'x', -expand=>1);
 $rW014 = $rW012 -> Button ( -command => sub{&main::deleteGlobal($rW024)}, -background=>'#ffffff', -text=>'Delete', -state=>'normal' ) -> pack(-anchor=>'nw', -side=>'left', -fill=>'x', -expand=>1);
-$rW024 = $rLeftFrame -> Scrolled ( 'Listbox', -background=>'#ffffff', -selectmode=>'single', -relief=>'sunken', -scrollbars=>'se' )->pack(-side => 'top', -anchor =>  'nw', -expand => 1, fill => 'both');
+$rW024 = $rLeftFrame -> Scrolled ( 'Listbox', -background=>'#ffffff', -selectmode=>'single', -relief=>'sunken', -scrollbars=>'se' )->pack(-side => 'top', -anchor =>  'nw', -expand => 1, -fill => 'both');
 $rRightFrame = $mw -> LabFrame ( -borderwidth=>1, -label=>'Local variables', -relief=>'ridge', -labelside=>'acrosstop' ) -> pack(-anchor=>'ne', -side=>'right', -fill=>'both', -expand=>1);
 $rW021 = $rRightFrame -> Frame ( -relief=>'flat' ) -> pack(-anchor=>'sw', -side=>'bottom', -fill=>'x', -expand=>1);
 $rW013x = $rW021 -> Button (-command => sub{&main::addLocal($rW020)}, -background=>'#ffffff', -text=>'Add', -state=>'normal' ) -> pack(-anchor=>'nw', -side=>'left', -fill=>'x', -expand=>1);
